==> igblastr_0.99.7.tar.gz: igblastr/man/install_IMGT_germline_db.Rd <==
\name{install_IMGT_germline_db}

\alias{install_IMGT_germline_db}
\alias{list_IMGT_releases}
\alias{list_IMGT_organisms}
\alias{IMGT_is_up}

\title{Install a germline db from IMGT}

\description{
  The \code{install_IMGT_germline_db()} function downloads IMGT/V-QUEST
  germline sequences (FASTA files) from the IMGT website, and generates
  a small local database with the sequences of the specified organism.
  This local database can then be used later with \code{\link{igblastn}()}.

  Note that \code{install_IMGT_germline_db()} generates the
  local database by performing the instructions provided at
  \url{https://ncbi.github.io/igblast/cook/How-to-set-up.html}.
  In particular, utility tool \emph{edit_imgt_file.pl} (Perl script
  included in the IgBLAST installation) is invoked to process the
  sequences. This means that Perl must be available on your machine.
}

\usage{
install_IMGT_germline_db(release, organism="Homo sapiens",
                         force=FALSE, ...)

## Related utilities:
list_IMGT_releases(recache=FALSE)
list_IMGT_organisms(release)
IMGT_is_up()
}

\arguments{
  \item{release}{
    A single string specifying the IMGT/V-QUEST release to get the
    germline sequences from (or to list the organisms from for
    \code{list_IMGT_organisms()}).
    Use \code{list_IMGT_releases()} to list all releases.
  }
  \item{organism}{
    A single string specifying the organism for which to get the germline
    sequences.
  }
  \item{force}{
    Set to \code{TRUE} to reinstall if the requested database is already
    installed.
  }
  \item{...}{
    Extra arguments to be passed to the internal call to \code{download.file()}.
    See \code{?\link[utils]{download.file}} in the \pkg{utils} package for
    more information.
  }
  \item{recache}{
    \code{list_IMGT_releases()} uses a caching mechanism so that the
    list of IMGT/V-QUEST releases gets downloaded only once from the IMGT
    website during an R session (note that this caching is done in memory
    so it does not persist across sessions).
    Set \code{recache} to \code{TRUE} to force a new download (and
    recaching) of the list of IMGT/V-QUEST releases.
  }
}

\value{
  \code{install_IMGT_germline_db()} returns the name to the local
  germline db as an invisible string.

  \code{list_IMGT_releases()} returns the list of IMGT/V-QUEST releases
  in a character vector. The releases are sorted from newest to oldest
  (latest release is first).

  \code{list_IMGT_organisms()} returns the list of organisms included
  in the specified IMGT/V-QUEST release in a character vector.

  \code{IMGT_is_up()} returns \code{TRUE} or \code{FALSE}, indicating
  whether the IMGT website at \url{https://www.imgt.org} is up and running
  or down.
}

\seealso{
  \itemize{
    \item The \code{\link{igblastn}} function to run the \code{igblastn}
          \emph{standalone executable} included in IgBLAST from R. This
          is the main function in the \pkg{igblastr} package.

    \item \code{\link{use_germline_db}} to select the local germline db
          to use with \code{igblastn()}.

    \item The IMGT website: \url{https://www.imgt.org/}.

    \item The IMGT/V-QUEST download site:
          \url{https://www.imgt.org/download/V-QUEST/}.

    \item IgBLAST is described at
          \url{https://pubmed.ncbi.nlm.nih.gov/23671333/}.
  }
}

\examples{
if (!has_igblast()) install_igblast()

if (IMGT_is_up()) {
  ## As of March 26, 2025, the latest IMGT/V-QUEST release is 202506-1:
  list_IMGT_releases()

  list_IMGT_organisms("202506-1")

  ## Download germline sequences from IMGT/V-QUEST 202506-1, and store
  ## the IG sequences for Mouse in a local database:
  install_IMGT_germline_db("202506-1", organism="Mus musculus", force=TRUE)

  ## List the local germline databases:
  list_germline_dbs()

  ## Tell igblastn() to use the newly installed germline db:
  use_germline_db("IMGT-202506-1.Mus_musculus.IGH+IGK+IGL")
}
}

\keyword{utilities}

==> igblastr_0.99.11.tar.gz: igblastr/man/install_IMGT_germline_db.Rd <==
\name{install_IMGT_germline_db}

\alias{install_IMGT_germline_db}
\alias{list_IMGT_releases}
\alias{list_IMGT_organisms}
\alias{IMGT_is_up}

\title{Install a germline db from IMGT}

\description{
  The \code{install_IMGT_germline_db()} function downloads IMGT/V-QUEST
  germline sequences from the IMGT website for a given organism, and
  stores them in a local germline database. This local database gets
  installed in \pkg{igblastr}'s persistent cache. It can then be used
  later with \code{\link{igblastn}()}.
}

\usage{
install_IMGT_germline_db(release, organism="Homo sapiens",
                         force=FALSE, ...)

## Related utilities:
list_IMGT_releases(recache=FALSE)
list_IMGT_organisms(release)
IMGT_is_up()
}

\arguments{
  \item{release}{
    A single string specifying the IMGT/V-QUEST release to get the
    germline sequences from (or to list the organisms from for
    \code{list_IMGT_organisms()}).
    Use \code{list_IMGT_releases()} to list all releases.
  }
  \item{organism}{
    A single string specifying the organism for which to get the germline
    sequences.
  }
  \item{force}{
    Set to \code{TRUE} to reinstall if the requested database is already
    installed.
  }
  \item{...}{
    Extra arguments to be passed to the internal call to \code{download.file()}.
    See \code{?\link[utils]{download.file}} in the \pkg{utils} package for
    more information.
  }
  \item{recache}{
    \code{list_IMGT_releases()} uses a caching mechanism so that the
    list of IMGT/V-QUEST releases gets downloaded only once from the IMGT
    website during an R session (note that this caching is done in memory
    so it does not persist across sessions).
    Set \code{recache} to \code{TRUE} to force a new download (and
    recaching) of the list of IMGT/V-QUEST releases.
  }
}

\value{
  \code{install_IMGT_germline_db()} returns the name to the newly
  installed germline db as an invisible string.

  \code{list_IMGT_releases()} returns the list of IMGT/V-QUEST releases
  in a character vector. The releases are sorted from newest to oldest
  (latest release is first).

  \code{list_IMGT_organisms()} returns the list of organisms included
  in the specified IMGT/V-QUEST release in a character vector.

  \code{IMGT_is_up()} returns \code{TRUE} or \code{FALSE}, indicating
  whether the IMGT website at \url{https://www.imgt.org} is up and running
  or down.
}

\note{
  \code{install_IMGT_germline_db()} generates the local
  database by performing the instructions provided at
  \url{https://ncbi.github.io/igblast/cook/How-to-set-up.html}.

  In particular, utility tool \emph{edit_imgt_file.pl} (Perl script
  included in the IgBLAST installation) is invoked to process the
  sequences. This means that Perl must be available on your machine.
}

\seealso{
  \itemize{
    \item The \code{\link{igblastn}} function to run the \code{igblastn}
          \emph{standalone executable} included in IgBLAST from R. This
          is the main function in the \pkg{igblastr} package.

    \item \code{\link{use_germline_db}} to select the cached germline db
          to use with \code{igblastn()}.

    \item The IMGT website: \url{https://www.imgt.org/}.

    \item The IMGT/V-QUEST download site:
          \url{https://www.imgt.org/download/V-QUEST/}.

    \item IgBLAST is described at
          \url{https://pubmed.ncbi.nlm.nih.gov/23671333/}.
  }
}

\examples{
if (!has_igblast()) install_igblast()

if (IMGT_is_up()) {
  ## As of March 26, 2025, the latest IMGT/V-QUEST release is 202506-1:
  list_IMGT_releases()

  list_IMGT_organisms("202506-1")

  ## Download Mouse germline sequences from IMGT/V-QUEST 202506-1, and
  ## store them in a cached germline database:
  install_IMGT_germline_db("202506-1", organism="Mus musculus", force=TRUE)

  ## List the cached germline databases:
  list_germline_dbs()

  ## Tell igblastn() to use the newly installed germline db:
  use_germline_db("IMGT-202506-1.Mus_musculus.IGH+IGK+IGL")
}
}

\keyword{utilities}
